@@ -10,16 +10,16 @@ from RepoAuditor.Plugins.GitHub.Impl.EnableRulesetRequirementImpl import EnableR
 
 
 class RequireSignedCommits(EnableRulesetRequirementImpl):
-    """Require signed commits."""
+    """Check that the "Require signed commits" rule is disabled."""
 
     def __init__(self) -> None:
         super().__init__(
-            name="RequireSignedCommits",
-            enabled_by_default=False,
-            dynamic_arg_name="enabled",
+            name="RequireSignedCommitsRule",
+            enabled_by_default=True,
+            dynamic_arg_name="disabled",
             github_ruleset_type="required_signatures",
-            github_ruleset_value="Signed Commits",
+            github_ruleset_value="Require signed commits",
             get_configuration_value_func=lambda rule: rule.get("type", "") == "required_signatures",
-            resolution="Enable commit signing requirement in repository rulesets",
+            resolution="{__enabled_str} commit signing requirement in repository rulesets",
             rationale="Signed commits ensure commit authenticity",
         )
