@@ -24,12 +24,24 @@ pytest.fixture(InitializeStreamCapabilities(), scope="session", autouse=True)
 
 # ----------------------------------------------------------------------
 def test_Successful(pat_args, snapshot):
+    """Test if all requirements of the GitHub plugin successfully pass."""
     result = CliRunner().invoke(app, pat_args)
 
     assert result.exit_code == 0, result.output
     assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
 
+# ----------------------------------------------------------------------
+def test_Successful_To_File(pat_args, tmp_path, snapshot):
+    """Test if all requirements of the GitHub plugin successfully pass and the output is written to a file."""
+    output = tmp_path / "repo_auditor_output.txt"
+    result = CliRunner().invoke(app, pat_args + ["--output", str(output), "--verbose"])
+
+    assert result.exit_code == 0, result.output
+    with open(output, mode="r") as file:
+        assert ScrubDurationGithuburlAndSpaces(file.read()) == snapshot
+
+
 # ----------------------------------------------------------------------
 def _skip_test_NoPAT():
     operating_system = os.getenv("GITHUB_CI_OPERATING_SYSTEM")
@@ -49,6 +61,7 @@ def _skip_test_NoPAT():
     reason="Only run this test on the CI machine in specific configurations to avoid GitHub's request throttling.",
 )
 def test_NoPAT(snapshot, args):
+    """Only run this test for specific CI conditions."""
     result = CliRunner().invoke(app, args)
 
     assert result.exit_code == 1, result.output
@@ -59,14 +72,14 @@ def test_NoPAT(snapshot, args):
 class TestStandard:
     # ----------------------------------------------------------------------
     def test_NoAutoMerge(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-AutoMerge-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-AutoMerge-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoDeleteHeadBranches(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-DeleteHeadBranches-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-DeleteHeadBranches-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
@@ -80,14 +93,14 @@ class TestStandard:
 
     # ----------------------------------------------------------------------
     def test_NoMergeCommit(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-MergeCommit-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-MergeCommit-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesRebaseMergeCommit(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RebaseMergeCommit-true"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-RebaseMergeCommit-enabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
@@ -108,56 +121,56 @@ class TestStandard:
 
     # ----------------------------------------------------------------------
     def test_YesSquashCommitMerge(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SquashCommitMerge-true"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SquashCommitMerge-enabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesSuggestUpdatingPullRequestBranches(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SuggestUpdatingPullRequestBranches-true"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SuggestUpdatingPullRequestBranches-enabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesSupportDiscussions(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportDiscussions-true"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportDiscussions-enabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportIssues(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportIssues-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportIssues-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportProjects(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportProjects-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportProjects-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportWikis(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportWikis-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportWikis-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesTemplateRepository(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-TemplateRepository-true"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-TemplateRepository-enabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoWebCommitSignoff(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-WebCommitSignoff-false"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-WebCommitSignoff-disabled"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
@@ -169,9 +182,37 @@ class TestStandard:
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
+    # ----------------------------------------------------------------------
+    def test_NoDescription(self, pat_args, snapshot, monkeypatch):
+        """Test if no repository description is available.
+        The way this test works is that we use the default `--GitHub-Description-allow-empty=false`
+        and monkey-patch the response to set `description` to empty.
+        """
+        from RepoAuditor.Plugins.GitHub.StandardQuery import StandardQuery
+
+        def MockedGetData(
+            self,
+            module_data,
+        ):
+            """Monkey-patched class method to set description to empty."""
+            response = module_data["session"].get("").json()
+            response["description"] = ""
+            module_data["standard"] = response
+            return module_data
+
+        monkeypatch.setattr(StandardQuery, "GetData", MockedGetData)
+
+        result = CliRunner().invoke(app, pat_args)
+
+        assert result.exit_code == -1, result.output
+        assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
+
     # ----------------------------------------------------------------------
     def test_LicenseValue(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-License-value", "Not the MIT License"])
+        result = CliRunner().invoke(
+            app,
+            pat_args + ["--GitHub-License-value", "Not the MIT License"],
+        )
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
@@ -194,7 +235,7 @@ class TestStandard:
     def test_PrivateValue(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-Private-true"],
+            pat_args + ["--GitHub-Private-enabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -218,7 +259,7 @@ class TestStandard:
     def test_Protected(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-Protected-false"],
+            pat_args + ["--GitHub-Protected-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -231,7 +272,7 @@ class TestClassic:
     def test_AllowDeletions(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-AllowDeletions-true"],
+            pat_args + ["--GitHub-AllowDeletions-enabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -241,7 +282,7 @@ class TestClassic:
     def test_AllowMainlineForcePush(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-AllowMainlineForcePushes-true"],
+            pat_args + ["--GitHub-AllowMainlineForcePushes-enabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -251,7 +292,7 @@ class TestClassic:
     def test_DismissStalePullRequestApprovals(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-DismissStalePullRequestApprovals-false"],
+            pat_args + ["--GitHub-DismissStalePullRequestApprovals-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -261,7 +302,7 @@ class TestClassic:
     def test_DoNotAllowBypassSettings(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-DoNotAllowBypassSettings-false"],
+            pat_args + ["--GitHub-DoNotAllowBypassSettings-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -271,7 +312,7 @@ class TestClassic:
     def test_EnsureStatusChecks(self, pat_args):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-EnsureStatusChecks-disable", "--verbose"],
+            pat_args + ["--GitHub-EnsureStatusChecks-disabled", "--verbose"],
         )
 
         assert result.exit_code == 0, result.output
@@ -281,7 +322,7 @@ class TestClassic:
     def test_RequireApprovalMostRecentPush(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireApprovalMostRecentPush-false"],
+            pat_args + ["--GitHub-RequireApprovalMostRecentPush-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -301,7 +342,7 @@ class TestClassic:
     def test_RequireCodeOwnerReview(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireCodeOwnerReview-true"],
+            pat_args + ["--GitHub-RequireCodeOwnerReview-enabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -311,7 +352,7 @@ class TestClassic:
     def test_RequireConversationResolution(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireConversationResolution-false"],
+            pat_args + ["--GitHub-RequireConversationResolution-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -321,7 +362,7 @@ class TestClassic:
     def test_RequireLinearHistory(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireLinearHistory-true"],
+            pat_args + ["--GitHub-RequireLinearHistory-enabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -331,7 +372,7 @@ class TestClassic:
     def test_RequirePullRequests(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequirePullRequests-false"],
+            pat_args + ["--GitHub-RequirePullRequests-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -341,7 +382,7 @@ class TestClassic:
     def test_RequireSignedCommits(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireSignedCommits-false"],
+            pat_args + ["--GitHub-RequireSignedCommits-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -351,7 +392,7 @@ class TestClassic:
     def test_RequireStatusChecksToPass(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireStatusChecksToPass-false"],
+            pat_args + ["--GitHub-RequireStatusChecksToPass-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -361,7 +402,7 @@ class TestClassic:
     def test_RequireUpToDateBranches(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireUpToDateBranches-false"],
+            pat_args + ["--GitHub-RequireUpToDateBranches-disabled"],
         )
 
         assert result.exit_code == -1, result.output
@@ -370,26 +411,55 @@ class TestClassic:
 
 # ----------------------------------------------------------------------
 class TestRulesets:
-    """End-to-end tests for rulesets in a GitHub repository."""
+    """End-to-end tests for enabled/disabled rules within a ruleset in a GitHub repository."""
+
+    def test_Default(self, pat_args, snapshot, monkeypatch):
+        """Test for default case when no rulesets are present on the branch."""
+
+        from RepoAuditor.Plugins.GitHub.RulesetQuery import RulesetQuery
+
+        def MockGetData(
+            self,
+            module_data,
+        ):
+            """Mock version for GetData for RulesetQuery"""
+            # Specify empty ruleset data as the default
+            module_data["rules"] = []
+
+            return module_data
+
+        monkeypatch.setattr(RulesetQuery, "GetData", MockGetData)
+
+        result = CliRunner().invoke(app, pat_args)
+
+        # Error since no enabled rulesets
+        assert result.exit_code == -1, result.output
+        assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     def test_RequireStatusChecks(self, pat_args, snapshot):
-        """Test for Status Checks not required ruleset"""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireStatusChecks-enabled"])
+        """Test for requirement `Require status checks to pass` is disabled in the ruleset for the `main` branch."""
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireStatusChecksRule-disabled"])
 
+        # Since the repo ruleset has the requirement enabled,
+        # we should get an error.
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     def test_RequirePullRequests(self, pat_args, snapshot):
-        """Test for Pull Requests required ruleset"""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequirePullRequests-enabled"])
+        """Test for requirement `Require a pull request before merging` is disabled in the ruleset for the `main` branch."""
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequirePullRequestsRule-disabled"])
 
+        # Since the repo ruleset has the requirement disabled,
+        # we should get an error.
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     def test_RequireSignedCommits(self, pat_args, snapshot):
-        """Test for Signed Commits required ruleset"""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireSignedCommits-enabled"])
+        """Test for requirement `Require signed commits` is disabled in the ruleset for the `main` branch."""
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireSignedCommitsRule-disabled"])
 
+        # Since the repo ruleset has the requirement disabled,
+        # we should get an error.
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
@@ -397,8 +467,9 @@ class TestRulesets:
 # ----------------------------------------------------------------------
 # ----------------------------------------------------------------------
 # ----------------------------------------------------------------------
-@pytest.fixture
-def args() -> list[str]:
+@pytest.fixture(name="args")
+def args_fixture() -> list[str]:
+    """Common arguments for GitHub plugin and corresponding URL."""
     return [
         "--include",
         "GitHub",
@@ -408,12 +479,9 @@ def args() -> list[str]:
 
 
 # ----------------------------------------------------------------------
-@pytest.fixture
-def pat_args(args) -> list[str]:
-    _github_pat_filename = (Path(__file__).parent / "github_pat.txt").resolve()
-    CheckPATFileExists(_github_pat_filename)
+@pytest.fixture(name="pat_args")
+def pat_args_fixture(args) -> list[str]:
+    github_pat_filename = (Path(__file__).parent / "github_pat.txt").resolve()
+    CheckPATFileExists(github_pat_filename)
 
-    with _github_pat_filename.open() as f:
-        pat_value = f.read().strip()
-
-    return args + ["--GitHub-pat", pat_value]
+    return args + ["--GitHub-pat", str(github_pat_filename)]
